@@ -4,6 +4,7 @@ from typing import Dict, Any, Optional
 from slack_sdk.audit_logs.v1.logs import LogsResponse
 
 
+# TODO: Unlike WebClient's responses, this class has not yet provided __iter__ method
 class AuditLogsResponse:
     url: str
     status_code: int
@@ -12,8 +13,8 @@ class AuditLogsResponse:
     body: Optional[Dict[str, Any]]
     typed_body: Optional[LogsResponse]
 
-    @property
-    def typed_body(self) -> Optional[LogsResponse]:  # type: ignore
+    @property  # type: ignore[no-redef]
+    def typed_body(self) -> Optional[LogsResponse]:
         if self.body is None:
             return None
         return LogsResponse(**self.body)
@@ -30,8 +31,4 @@ class AuditLogsResponse:
         self.status_code = status_code
         self.headers = headers
         self.raw_body = raw_body
-        self.body = (
-            json.loads(raw_body)
-            if raw_body is not None and raw_body.startswith("{")
-            else None
-        )
+        self.body = json.loads(raw_body) if raw_body is not None and raw_body.startswith("{") else None
