@@ -1,6 +1,6 @@
 import asyncio
 import random
-from typing import Optional, List
+from typing import Optional, List, Type
 
 from aiohttp import ServerDisconnectedError, ServerConnectionError, ClientOSError
 
@@ -19,7 +19,7 @@ class AsyncConnectionErrorRetryHandler(AsyncRetryHandler):
         self,
         max_retry_count: int = 1,
         interval_calculator: RetryIntervalCalculator = default_interval_calculator,
-        error_types: List[Exception] = [
+        error_types: List[Type[Exception]] = [
             ServerConnectionError,
             ServerDisconnectedError,
             # ClientOSError: [Errno 104] Connection reset by peer
@@ -54,10 +54,10 @@ class AsyncRateLimitErrorRetryHandler(AsyncRetryHandler):
         *,
         state: RetryState,
         request: HttpRequest,
-        response: Optional[HttpResponse],
-        error: Optional[Exception],
+        response: Optional[HttpResponse] = None,
+        error: Optional[Exception] = None,
     ) -> bool:
-        return response.status_code == 429
+        return response is not None and response.status_code == 429
 
     async def prepare_for_next_attempt_async(
         self,
@@ -68,7 +68,7 @@ class AsyncRateLimitErrorRetryHandler(AsyncRetryHandler):
         error: Optional[Exception] = None,
     ) -> None:
         if response is None:
-            raise error
+            raise error  # type: ignore[misc]
 
         state.next_attempt_requested = True
         retry_after_header_name: Optional[str] = None
@@ -79,14 +79,33 @@ class AsyncRateLimitErrorRetryHandler(AsyncRetryHandler):
         duration = 1
         if retry_after_header_name is None:
             # This situation usually does not arise. Just in case.
-            duration += random.random()
+            duration += random.random()  # type: ignore[assignment]
         else:
-            duration = (
-                int(response.headers.get(retry_after_header_name)[0]) + random.random()
-            )
+            duration = int(response.headers.get(retry_after_header_name)[0]) + random.random()  # type: ignore[assignment, index] # noqa: E501
         await asyncio.sleep(duration)
         state.increment_current_attempt()
 
 
+class AsyncServerErrorRetryHandler(AsyncRetryHandler):
+    """RetryHandler that does retries for server errors."""
+
+    def __init__(
+        self,
+        max_retry_count: int = 1,
+        interval_calculator: RetryIntervalCalculator = default_interval_calculator,
+    ):
+        super().__init__(max_retry_count, interval_calculator)
+
+    async def _can_retry_async(
+        self,
+        *,
+        state: RetryState,
+        request: HttpRequest,
+        response: Optional[HttpResponse] = None,
+        error: Optional[Exception] = None,
+    ) -> bool:
+        return response is not None and response.status_code in [500, 503]
+
+
 def async_default_handlers() -> List[AsyncRetryHandler]:
     return [AsyncConnectionErrorRetryHandler()]
