@@ -8,13 +8,14 @@ from slack_sdk.models.basic_objects import (
     JsonObject,
     JsonValidator,
 )
-from .basic_components import MarkdownTextObject
+from .basic_components import MarkdownTextObject, SlackFile
 from .basic_components import PlainTextObject
 from .basic_components import TextObject
-from .block_elements import BlockElement
+from .block_elements import BlockElement, RichTextElement
 from .block_elements import ImageElement
 from .block_elements import InputInteractiveElement
 from .block_elements import InteractiveElement
+from ...errors import SlackObjectFormationError
 
 
 # -------------------------------------------------
@@ -32,7 +33,7 @@ class Block(JsonObject):
     block_id_max_length = 255
     logger = logging.getLogger(__name__)
 
-    def _subtype_warning(self):  # skipcq: PYL-R0201
+    def _subtype_warning(self):
         warnings.warn(
             "subtype is deprecated since slackclient 2.6.0, use type instead",
             DeprecationWarning,
@@ -45,7 +46,7 @@ class Block(JsonObject):
     def __init__(
         self,
         *,
-        type: Optional[str] = None,  # skipcq: PYL-W0622
+        type: Optional[str] = None,
         subtype: Optional[str] = None,  # deprecated
         block_id: Optional[str] = None,
     ):
@@ -61,14 +62,14 @@ class Block(JsonObject):
 
     @classmethod
     def parse(cls, block: Union[dict, "Block"]) -> Optional["Block"]:
-        if block is None:  # skipcq: PYL-R1705
+        if block is None:
             return None
         elif isinstance(block, Block):
             return block
         else:
             if "type" in block:
-                type = block["type"]  # skipcq: PYL-W0622
-                if type == SectionBlock.type:  # skipcq: PYL-R1705
+                type = block["type"]
+                if type == SectionBlock.type:
                     return SectionBlock(**block)
                 elif type == DividerBlock.type:
                     return DividerBlock(**block)
@@ -88,6 +89,8 @@ class Block(JsonObject):
                     return HeaderBlock(**block)
                 elif type == VideoBlock.type:
                     return VideoBlock(**block)
+                elif type == RichTextBlock.type:
+                    return RichTextBlock(**block)
                 else:
                     cls.logger.warning(f"Unknown block detected and skipped ({block})")
                     return None
@@ -97,7 +100,7 @@ class Block(JsonObject):
 
     @classmethod
     def parse_all(cls, blocks: Optional[Sequence[Union[dict, "Block"]]]) -> List["Block"]:
-        return [cls.parse(b) for b in blocks or []]
+        return [cls.parse(b) for b in blocks or []]  # type: ignore[misc]
 
 
 # -------------------------------------------------
@@ -111,8 +114,8 @@ class SectionBlock(Block):
     text_max_length = 3000
 
     @property
-    def attributes(self) -> Set[str]:
-        return super().attributes.union({"text", "fields", "accessory"})
+    def attributes(self) -> Set[str]:  # type: ignore[override]
+        return super().attributes.union({"text", "fields", "accessory", "expand"})
 
     def __init__(
         self,
@@ -121,6 +124,7 @@ class SectionBlock(Block):
         text: Optional[Union[str, dict, TextObject]] = None,
         fields: Optional[Sequence[Union[str, dict, TextObject]]] = None,
         accessory: Optional[Union[dict, BlockElement]] = None,
+        expand: Optional[bool] = None,
         **others: dict,
     ):
         """A section is one of the most flexible blocks available.
@@ -141,28 +145,33 @@ class SectionBlock(Block):
                 in a compact format that allows for 2 columns of side-by-side text.
                 Maximum number of items is 10. Maximum length for the text in each item is 2000 characters.
             accessory: One of the available element objects.
+            expand: Whether or not this section block's text should always expand when rendered.
+                If false or not provided, it may be rendered with a 'see more' option to expand and show the full text.
+                For AI Assistant apps, this allows the app to post long messages without users needing
+                to click 'see more' to expand the message.
         """
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
 
-        self.text = TextObject.parse(text)
+        self.text = TextObject.parse(text)  # type: ignore[arg-type]
         field_objects = []
         for f in fields or []:
             if isinstance(f, str):
                 field_objects.append(MarkdownTextObject.from_str(f))
             elif isinstance(f, TextObject):
-                field_objects.append(f)
+                field_objects.append(f)  # type: ignore[arg-type]
             elif isinstance(f, dict) and "type" in f:
                 d = copy.copy(f)
                 t = d.pop("type")
                 if t == MarkdownTextObject.type:
                     field_objects.append(MarkdownTextObject(**d))
                 else:
-                    field_objects.append(PlainTextObject(**d))
+                    field_objects.append(PlainTextObject(**d))  # type: ignore[arg-type]
             else:
                 self.logger.warning(f"Unsupported filed detected and skipped {f}")
         self.fields = field_objects
-        self.accessory = BlockElement.parse(accessory)
+        self.accessory = BlockElement.parse(accessory)  # type: ignore[arg-type]
+        self.expand = expand
 
     @JsonValidator("text or fields attribute must be specified")
     def _validate_text_or_fields_populated(self):
@@ -204,8 +213,8 @@ class ImageBlock(Block):
     type = "image"
 
     @property
-    def attributes(self) -> Set[str]:
-        return super().attributes.union({"alt_text", "image_url", "title"})
+    def attributes(self) -> Set[str]:  # type: ignore[override]
+        return super().attributes.union({"alt_text", "image_url", "title", "slack_file"})
 
     image_url_max_length = 3000
     alt_text_max_length = 2000
@@ -214,9 +223,10 @@ class ImageBlock(Block):
     def __init__(
         self,
         *,
-        image_url: str,
         alt_text: str,
-        title: Optional[Union[str, dict, TextObject]] = None,
+        image_url: Optional[str] = None,
+        slack_file: Optional[Union[Dict[str, Any], SlackFile]] = None,
+        title: Optional[Union[str, dict, PlainTextObject]] = None,
         block_id: Optional[str] = None,
         **others: dict,
     ):
@@ -224,10 +234,11 @@ class ImageBlock(Block):
         https://api.slack.com/reference/block-kit/blocks#image
 
         Args:
-            image_url (required): The URL of the image to be displayed.
-                Maximum length for this field is 3000 characters.
             alt_text (required): A plain-text summary of the image. This should not contain any markup.
                 Maximum length for this field is 2000 characters.
+            image_url: The URL of the image to be displayed.
+                Maximum length for this field is 3000 characters.
+            slack_file: A Slack image file object that defines the source of the image.
             title: An optional title for the image in the form of a text object that can only be of type: plain_text.
                 Maximum length for the text in this field is 2000 characters.
             block_id: A string acting as a unique identifier for a block. If not specified, one will be generated.
@@ -240,11 +251,27 @@ class ImageBlock(Block):
 
         self.image_url = image_url
         self.alt_text = alt_text
-        self.title = TextObject.parse(title)
+        parsed_title = None
+        if title is not None:
+            if isinstance(title, str):
+                parsed_title = PlainTextObject(text=title)
+            elif isinstance(title, dict):
+                if title.get("type") != PlainTextObject.type:
+                    raise SlackObjectFormationError(f"Unsupported type for title in an image block: {title.get('type')}")
+                parsed_title = PlainTextObject(text=title.get("text"), emoji=title.get("emoji"))  # type: ignore[arg-type]
+            elif isinstance(title, PlainTextObject):
+                parsed_title = title
+            else:
+                raise SlackObjectFormationError(f"Unsupported type for title in an image block: {type(title)}")
+        if slack_file is not None:
+            self.slack_file = (
+                slack_file if slack_file is None or isinstance(slack_file, SlackFile) else SlackFile(**slack_file)
+            )
+        self.title = parsed_title
 
     @JsonValidator(f"image_url attribute cannot exceed {image_url_max_length} characters")
     def _validate_image_url_length(self):
-        return len(self.image_url) <= self.image_url_max_length
+        return self.image_url is None or len(self.image_url) <= self.image_url_max_length
 
     @JsonValidator(f"alt_text attribute cannot exceed {alt_text_max_length} characters")
     def _validate_alt_text_length(self):
@@ -260,7 +287,7 @@ class ActionsBlock(Block):
     elements_max_length = 25
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union({"elements"})
 
     def __init__(
@@ -298,7 +325,7 @@ class ContextBlock(Block):
     elements_max_length = 10
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union({"elements"})
 
     def __init__(
@@ -334,7 +361,7 @@ class InputBlock(Block):
     hint_max_length = 2000
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union({"label", "hint", "element", "optional", "dispatch_action"})
 
     def __init__(
@@ -373,8 +400,8 @@ class InputBlock(Block):
         show_unknown_key_warning(self, others)
 
         self.label = TextObject.parse(label, default_type=PlainTextObject.type)
-        self.element = BlockElement.parse(element)
-        self.hint = TextObject.parse(hint, default_type=PlainTextObject.type)
+        self.element = BlockElement.parse(element)  # type: ignore[arg-type]
+        self.hint = TextObject.parse(hint, default_type=PlainTextObject.type)  # type: ignore[arg-type]
         self.dispatch_action = dispatch_action
         self.optional = optional
 
@@ -400,7 +427,7 @@ class FileBlock(Block):
     type = "file"
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union({"external_id", "source"})
 
     def __init__(
@@ -433,7 +460,7 @@ class CallBlock(Block):
     type = "call"
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union({"call_id", "api_decoration_available", "call"})
 
     def __init__(
@@ -461,7 +488,7 @@ class HeaderBlock(Block):
     text_max_length = 150
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union({"text"})
 
     def __init__(
@@ -485,7 +512,7 @@ class HeaderBlock(Block):
         super().__init__(type=self.type, block_id=block_id)
         show_unknown_key_warning(self, others)
 
-        self.text = TextObject.parse(text, default_type=PlainTextObject.type)
+        self.text = TextObject.parse(text, default_type=PlainTextObject.type)  # type: ignore[arg-type]
 
     @JsonValidator("text attribute must be specified")
     def _validate_text(self):
@@ -502,7 +529,7 @@ class VideoBlock(Block):
     author_name_max_length = 50
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union(
             {
                 "alt_text",
@@ -561,9 +588,9 @@ class VideoBlock(Block):
         self.alt_text = alt_text
         self.video_url = video_url
         self.thumbnail_url = thumbnail_url
-        self.title = TextObject.parse(title, default_type=PlainTextObject.type)
+        self.title = TextObject.parse(title, default_type=PlainTextObject.type)  # type: ignore[arg-type]
         self.title_url = title_url
-        self.description = TextObject.parse(description, default_type=PlainTextObject.type)
+        self.description = TextObject.parse(description, default_type=PlainTextObject.type)  # type: ignore[arg-type]
         self.provider_icon_url = provider_icon_url
         self.provider_name = provider_name
         self.author_name = author_name
@@ -591,3 +618,34 @@ class VideoBlock(Block):
     @JsonValidator(f"author_name attribute cannot exceed {author_name_max_length} characters")
     def _validate_author_name_length(self):
         return self.author_name is None or len(self.author_name) < self.author_name_max_length
+
+
+class RichTextBlock(Block):
+    type = "rich_text"
+
+    @property
+    def attributes(self) -> Set[str]:  # type: ignore[override]
+        return super().attributes.union({"elements"})
+
+    def __init__(
+        self,
+        *,
+        elements: Sequence[Union[dict, RichTextElement]],
+        block_id: Optional[str] = None,
+        **others: dict,
+    ):
+        """A block that is used to hold interactive elements.
+        https://api.slack.com/reference/block-kit/blocks#rich_text
+
+        Args:
+            elements (required): An array of rich text objects -
+                rich_text_section, rich_text_list, rich_text_quote, rich_text_preformatted
+            block_id: A unique identifier for a block. If not specified, one will be generated.
+                Maximum length for this field is 255 characters.
+                block_id should be unique for each message or view and each iteration of a message or view.
+                If a message or view is updated, use a new block_id.
+        """
+        super().__init__(type=self.type, block_id=block_id)
+        show_unknown_key_warning(self, others)
+
+        self.elements = BlockElement.parse_all(elements)
