@@ -70,14 +70,9 @@ class DialogTextComponent(JsonObject, metaclass=ABCMeta):
     def label_length(self) -> bool:
         return len(self.label) < self.label_max_length
 
-    @JsonValidator(
-        f"placeholder attribute cannot exceed {placeholder_max_length} characters"
-    )
+    @JsonValidator(f"placeholder attribute cannot exceed {placeholder_max_length} characters")
     def placeholder_length(self) -> bool:
-        return (
-            self.placeholder is None
-            or len(self.placeholder) < self.placeholder_max_length
-        )
+        return self.placeholder is None or len(self.placeholder) < self.placeholder_max_length
 
     @JsonValidator(f"hint attribute cannot exceed {hint_max_length} characters")
     def hint_length(self) -> bool:
@@ -175,20 +170,15 @@ class AbstractDialogSelector(JsonObject, metaclass=ABCMeta):
     def label_length(self) -> bool:
         return len(self.label) < self.label_max_length
 
-    @JsonValidator(
-        f"placeholder attribute cannot exceed {placeholder_max_length} characters"
-    )
+    @JsonValidator(f"placeholder attribute cannot exceed {placeholder_max_length} characters")
     def placeholder_length(self) -> bool:
-        return (
-            self.placeholder is None
-            or len(self.placeholder) < self.placeholder_max_length
-        )
+        return self.placeholder is None or len(self.placeholder) < self.placeholder_max_length
 
     @EnumValidator("data_source", DataSourceTypes)
     def data_source_valid(self) -> bool:
         return self.data_source in self.DataSourceTypes
 
-    def to_dict(self) -> dict:  # skipcq: PYL-W0221
+    def to_dict(self) -> dict:
         json = super().to_dict()
         if self.data_source == "external":
             if isinstance(self.value, Option):
@@ -272,7 +262,7 @@ class DialogStaticSelector(AbstractDialogSelector):
 class DialogUserSelector(AbstractDialogSelector):
     data_source = "users"
 
-    def __init__(  # skipcq: PYL-W0235
+    def __init__(
         self,
         *,
         name: str,
@@ -310,7 +300,7 @@ class DialogUserSelector(AbstractDialogSelector):
 class DialogChannelSelector(AbstractDialogSelector):
     data_source = "channels"
 
-    def __init__(  # skipcq: PYL-W0235
+    def __init__(
         self,
         *,
         name: str,
@@ -346,7 +336,7 @@ class DialogChannelSelector(AbstractDialogSelector):
 class DialogConversationSelector(AbstractDialogSelector):
     data_source = "conversations"
 
-    def __init__(  # skipcq: PYL-W0235
+    def __init__(
         self,
         *,
         name: str,
@@ -384,7 +374,7 @@ class DialogExternalSelector(AbstractDialogSelector):
     data_source = "external"
 
     @property
-    def attributes(self) -> Set[str]:
+    def attributes(self) -> Set[str]:  # type: ignore[override]
         return super().attributes.union({"min_query_length"})
 
     def __init__(
@@ -424,14 +414,14 @@ class DialogExternalSelector(AbstractDialogSelector):
             name=name,
             label=label,
             value=value,
-            optional=optional,
+            optional=optional,  # type: ignore[arg-type]
             placeholder=placeholder,
         )
         self.min_query_length = min_query_length
 
 
 class DialogBuilder(JsonObject):
-    attributes = {}  # no attributes because to_dict has unique implementation
+    attributes = {}  # type: ignore[assignment] # no attributes because to_dict has unique implementation
 
     _callback_id: Optional[str]
     _elements: List[Union[DialogTextComponent, AbstractDialogSelector]]
@@ -837,10 +827,7 @@ class DialogBuilder(JsonObject):
 
     @JsonValidator(f"submit_label cannot exceed {submit_label_max_length} characters")
     def submit_label_length(self) -> bool:
-        return (
-            self._submit_label is None
-            or len(self._submit_label) <= self.submit_label_max_length
-        )
+        return self._submit_label is None or len(self._submit_label) <= self.submit_label_max_length
 
     @JsonValidator("submit_label can only be one word")
     def submit_label_valid(self) -> bool:
@@ -850,7 +837,7 @@ class DialogBuilder(JsonObject):
     def state_length(self) -> bool:
         return not self._state or len(self._state) <= self.state_max_length
 
-    def to_dict(self) -> dict:  # skipcq: PYL-W0221
+    def to_dict(self) -> dict:
         self.validate_json()
         json = {
             "title": self._title,
