@@ -26,10 +26,24 @@ class AsyncCacheableInstallationStore(AsyncInstallationStore):
     def logger(self) -> Logger:
         return self.underlying.logger
 
-    async def async_save(self, installation: Installation):
+    async def async_save(self, installation: Installation):  # type: ignore[explicit-override]
+        # Invalidate cache data for update operations
+        key = f"{installation.enterprise_id or ''}-{installation.team_id or ''}"
+        if key in self.cached_bots:
+            self.cached_bots.pop(key)
+        key = f"{installation.enterprise_id or ''}-{installation.team_id or ''}-{installation.user_id or ''}"
+        if key in self.cached_installations:
+            self.cached_installations.pop(key)
         return await self.underlying.async_save(installation)
 
-    async def async_find_bot(
+    async def async_save_bot(self, bot: Bot):  # type: ignore[explicit-override]
+        # Invalidate cache data for update operations
+        key = f"{bot.enterprise_id or ''}-{bot.team_id or ''}"
+        if key in self.cached_bots:
+            self.cached_bots.pop(key)
+        return await self.underlying.async_save_bot(bot)
+
+    async def async_find_bot(  # type: ignore[explicit-override]
         self,
         *,
         enterprise_id: Optional[str],
@@ -50,7 +64,7 @@ class AsyncCacheableInstallationStore(AsyncInstallationStore):
             self.cached_bots[key] = bot
         return bot
 
-    async def async_find_installation(
+    async def async_find_installation(  # type: ignore[explicit-override]
         self,
         *,
         enterprise_id: Optional[str],
@@ -98,8 +112,10 @@ class AsyncCacheableInstallationStore(AsyncInstallationStore):
             team_id=team_id,
             user_id=user_id,
         )
-        key = f"{enterprise_id or ''}-{team_id or ''}={user_id or ''}"
-        self.cached_installations.pop(key)
+        key_prefix = f"{enterprise_id or ''}-{team_id or ''}"
+        for key in list(self.cached_installations.keys()):
+            if key.startswith(key_prefix):
+                self.cached_installations.pop(key)
 
     async def async_delete_all(
         self,
@@ -112,9 +128,9 @@ class AsyncCacheableInstallationStore(AsyncInstallationStore):
             team_id=team_id,
         )
         key_prefix = f"{enterprise_id or ''}-{team_id or ''}"
-        for key in self.cached_bots.keys():
+        for key in list(self.cached_bots.keys()):
             if key.startswith(key_prefix):
                 self.cached_bots.pop(key)
-        for key in self.cached_installations.keys():
+        for key in list(self.cached_installations.keys()):
             if key.startswith(key_prefix):
                 self.cached_installations.pop(key)
