@@ -63,22 +63,24 @@ class FileInstallationStore(InstallationStore, AsyncInstallationStore):
 
             # per workspace per user
             u_id = installation.user_id or none
-            entity: str = json.dumps(installation.__dict__)
+            entity = json.dumps(installation.__dict__)
             with open(f"{team_installation_dir}/installer-{u_id}-latest", "w") as f:
                 f.write(entity)
-            with open(
-                f"{team_installation_dir}/installer-{u_id}-{history_version}", "w"
-            ) as f:
+            with open(f"{team_installation_dir}/installer-{u_id}-{history_version}", "w") as f:
                 f.write(entity)
 
         else:
             u_id = installation.user_id or none
             installer_filepath = f"{team_installation_dir}/installer-{u_id}-latest"
             with open(installer_filepath, "w") as f:
-                entity: str = json.dumps(installation.__dict__)
+                entity = json.dumps(installation.__dict__)
                 f.write(entity)
 
     def save_bot(self, bot: Bot):
+        if bot.bot_token is None:
+            self.logger.debug("Skipped saving a new row because of the absense of bot token in it")
+            return
+
         none = "none"
         e_id = bot.enterprise_id or none
         t_id = bot.team_id or none
@@ -95,7 +97,7 @@ class FileInstallationStore(InstallationStore, AsyncInstallationStore):
                 f.write(entity)
         else:
             with open(f"{team_installation_dir}/bot-latest", "w") as f:
-                entity: str = json.dumps(bot.__dict__)
+                entity = json.dumps(bot.__dict__)
                 f.write(entity)
 
     async def async_find_bot(
@@ -129,9 +131,7 @@ class FileInstallationStore(InstallationStore, AsyncInstallationStore):
                 data = json.loads(f.read())
                 return Bot(**data)
         except FileNotFoundError as e:
-            message = (
-                f"Installation data missing for enterprise: {e_id}, team: {t_id}: {e}"
-            )
+            message = f"Installation data missing for enterprise: {e_id}, team: {t_id}: {e}"
             self.logger.debug(message)
             return None
 
@@ -165,29 +165,47 @@ class FileInstallationStore(InstallationStore, AsyncInstallationStore):
             t_id = none
         installation_filepath = f"{self.base_dir}/{e_id}-{t_id}/installer-latest"
         if user_id is not None:
-            installation_filepath = (
-                f"{self.base_dir}/{e_id}-{t_id}/installer-{user_id}-latest"
-            )
+            installation_filepath = f"{self.base_dir}/{e_id}-{t_id}/installer-{user_id}-latest"
 
         try:
+            installation: Optional[Installation] = None
             with open(installation_filepath) as f:
                 data = json.loads(f.read())
-                return Installation(**data)
+                installation = Installation(**data)
+
+            has_user_installation = user_id is not None and installation is not None
+            no_bot_token_installation = installation is not None and installation.bot_token is None
+            should_find_bot_installation = has_user_installation or no_bot_token_installation
+            if should_find_bot_installation:
+                # Retrieve the latest bot token, just in case
+                # See also: https://github.com/slackapi/bolt-python/issues/664
+                latest_bot_installation = self.find_bot(
+                    enterprise_id=enterprise_id,
+                    team_id=team_id,
+                    is_enterprise_install=is_enterprise_install,
+                )
+                if latest_bot_installation is not None and installation.bot_token != latest_bot_installation.bot_token:
+                    # NOTE: this logic is based on the assumption that every single installation has bot scopes
+                    # If you need to installation patterns without bot scopes in the same S3 bucket,
+                    # please fork this code and implement your own logic.
+                    installation.bot_id = latest_bot_installation.bot_id
+                    installation.bot_user_id = latest_bot_installation.bot_user_id
+                    installation.bot_token = latest_bot_installation.bot_token
+                    installation.bot_scopes = latest_bot_installation.bot_scopes
+                    installation.bot_refresh_token = latest_bot_installation.bot_refresh_token
+                    installation.bot_token_expires_at = latest_bot_installation.bot_token_expires_at
+
+            return installation
+
         except FileNotFoundError as e:
-            message = (
-                f"Installation data missing for enterprise: {e_id}, team: {t_id}: {e}"
-            )
+            message = f"Installation data missing for enterprise: {e_id}, team: {t_id}: {e}"
             self.logger.debug(message)
             return None
 
-    async def async_delete_bot(
-        self, *, enterprise_id: Optional[str], team_id: Optional[str]
-    ) -> None:
+    async def async_delete_bot(self, *, enterprise_id: Optional[str], team_id: Optional[str]) -> None:
         return self.delete_bot(enterprise_id=enterprise_id, team_id=team_id)
 
-    def delete_bot(
-        self, *, enterprise_id: Optional[str], team_id: Optional[str]
-    ) -> None:
+    def delete_bot(self, *, enterprise_id: Optional[str], team_id: Optional[str]) -> None:
         none = "none"
         e_id = enterprise_id or none
         t_id = team_id or none
@@ -201,9 +219,7 @@ class FileInstallationStore(InstallationStore, AsyncInstallationStore):
         team_id: Optional[str],
         user_id: Optional[str] = None,
     ) -> None:
-        return self.delete_installation(
-            enterprise_id=enterprise_id, team_id=team_id, user_id=user_id
-        )
+        return self.delete_installation(enterprise_id=enterprise_id, team_id=team_id, user_id=user_id)
 
     def delete_installation(
         self,
