@@ -1,11 +1,8 @@
-import re
-from datetime import datetime  # type: ignore
+from datetime import datetime
 from time import time
 from typing import Optional, Union, Dict, Any, Sequence
 
-from slack_sdk.oauth.installation_store.internals import (
-    _from_iso_format_to_unix_timestamp,
-)
+from slack_sdk.oauth.installation_store.internals import _timestamp_to_type
 
 
 class Bot:
@@ -70,34 +67,17 @@ class Bot:
         else:
             self.bot_scopes = bot_scopes
         self.bot_refresh_token = bot_refresh_token
+
         if bot_token_expires_at is not None:
-            if type(bot_token_expires_at) == datetime:
-                self.bot_token_expires_at = int(bot_token_expires_at.timestamp())  # type: ignore
-            elif type(bot_token_expires_at) == str and not re.match(
-                "^\\d+$", bot_token_expires_at
-            ):
-                self.bot_token_expires_at = int(
-                    _from_iso_format_to_unix_timestamp(bot_token_expires_at)
-                )
-            else:
-                self.bot_token_expires_at = int(bot_token_expires_at)
+            self.bot_token_expires_at = _timestamp_to_type(bot_token_expires_at, int)
         elif bot_token_expires_in is not None:
             self.bot_token_expires_at = int(time()) + bot_token_expires_in
         else:
             self.bot_token_expires_at = None
+
         self.is_enterprise_install = is_enterprise_install or False
 
-        if type(installed_at) == float:
-            self.installed_at = installed_at  # type: ignore
-        elif type(installed_at) == datetime:
-            self.installed_at = installed_at.timestamp()  # type: ignore
-        elif type(installed_at) == str:
-            if re.match("^\\d+.\\d+$", installed_at):
-                self.installed_at = float(installed_at)
-            else:
-                self.installed_at = _from_iso_format_to_unix_timestamp(installed_at)
-        else:
-            raise ValueError(f"Unsupported data format for installed_at {installed_at}")
+        self.installed_at = _timestamp_to_type(installed_at, float)
 
         self.custom_values = custom_values if custom_values is not None else {}
 
@@ -107,8 +87,8 @@ class Bot:
     def get_custom_value(self, name: str) -> Optional[Any]:
         return self.custom_values.get(name)
 
-    def to_dict(self) -> Dict[str, Any]:
-        standard_values = {
+    def _to_standard_value_dict(self) -> Dict[str, Any]:
+        return {
             "app_id": self.app_id,
             "enterprise_id": self.enterprise_id,
             "enterprise_name": self.enterprise_name,
@@ -119,12 +99,17 @@ class Bot:
             "bot_user_id": self.bot_user_id,
             "bot_scopes": ",".join(self.bot_scopes) if self.bot_scopes else None,
             "bot_refresh_token": self.bot_refresh_token,
-            "bot_token_expires_at": datetime.utcfromtimestamp(self.bot_token_expires_at)
-            if self.bot_token_expires_at is not None
-            else None,
+            "bot_token_expires_at": (
+                datetime.utcfromtimestamp(self.bot_token_expires_at) if self.bot_token_expires_at is not None else None
+            ),
             "is_enterprise_install": self.is_enterprise_install,
             "installed_at": datetime.utcfromtimestamp(self.installed_at),
         }
+
+    def to_dict_for_copying(self) -> Dict[str, Any]:
+        return {"custom_values": self.custom_values, **self._to_standard_value_dict()}
+
+    def to_dict(self) -> Dict[str, Any]:
         # prioritize standard_values over custom_values
         # when the same keys exist in both
-        return {**self.custom_values, **standard_values}
+        return {**self.custom_values, **self._to_standard_value_dict()}
