@@ -76,13 +76,9 @@ class AsyncWebhookClient:
         self.session = session
         self.auth = auth
         self.default_headers = default_headers if default_headers else {}
-        self.default_headers["User-Agent"] = get_user_agent(
-            user_agent_prefix, user_agent_suffix
-        )
+        self.default_headers["User-Agent"] = get_user_agent(user_agent_prefix, user_agent_suffix)
         self.logger = logger if logger is not None else logging.getLogger(__name__)
-        self.retry_handlers = (
-            retry_handlers if retry_handlers is not None else async_default_handlers()
-        )
+        self.retry_handlers = retry_handlers if retry_handlers is not None else async_default_handlers()
 
         if self.proxy is None or len(self.proxy.strip()) == 0:
             env_variable = load_http_proxy_from_env(self.logger)
@@ -100,6 +96,7 @@ class AsyncWebhookClient:
         delete_original: Optional[bool] = None,
         unfurl_links: Optional[bool] = None,
         unfurl_media: Optional[bool] = None,
+        metadata: Optional[Dict[str, Any]] = None,
         headers: Optional[Dict[str, str]] = None,
     ) -> WebhookResponse:
         """Performs a Slack API request and returns the result.
@@ -113,6 +110,7 @@ class AsyncWebhookClient:
             delete_original: True if you use this option for response_url requests
             unfurl_links: Option to indicate whether text url should unfurl
             unfurl_media: Option to indicate whether media url should unfurl
+            metadata: Metadata attached to the message
             headers: Request headers to append only for this request
 
         Returns:
@@ -130,13 +128,12 @@ class AsyncWebhookClient:
                 "delete_original": delete_original,
                 "unfurl_links": unfurl_links,
                 "unfurl_media": unfurl_media,
+                "metadata": metadata,
             },
             headers=headers,
         )
 
-    async def send_dict(
-        self, body: Dict[str, Any], headers: Optional[Dict[str, str]] = None
-    ) -> WebhookResponse:
+    async def send_dict(self, body: Dict[str, Any], headers: Optional[Dict[str, str]] = None) -> WebhookResponse:
         """Performs a Slack API request and returns the result.
 
         Args:
@@ -147,14 +144,12 @@ class AsyncWebhookClient:
             Webhook response
         """
         return await self._perform_http_request(
-            body=_build_body(body),
+            body=_build_body(body),  # type: ignore[arg-type]
             headers=_build_request_headers(self.default_headers, headers),
         )
 
-    async def _perform_http_request(
-        self, *, body: Dict[str, Any], headers: Dict[str, str]
-    ) -> WebhookResponse:
-        body = json.dumps(body)
+    async def _perform_http_request(self, *, body: Dict[str, Any], headers: Dict[str, str]) -> WebhookResponse:
+        str_body: str = json.dumps(body)
         headers["Content-Type"] = "application/json;charset=utf-8"
 
         session: Optional[ClientSession] = None
@@ -173,14 +168,14 @@ class AsyncWebhookClient:
         try:
             request_kwargs = {
                 "headers": headers,
-                "data": body,
+                "data": str_body,
                 "ssl": self.ssl,
                 "proxy": self.proxy,
             }
             retry_request = RetryHttpRequest(
                 method="POST",
                 url=self.url,
-                headers=headers,
+                headers=headers,  # type: ignore[arg-type]
                 body_params=body,
             )
 
@@ -194,26 +189,22 @@ class AsyncWebhookClient:
                 response_body = ""
 
                 if self.logger.level <= logging.DEBUG:
-                    self.logger.debug(
-                        f"Sending a request - url: {self.url}, body: {body}, headers: {headers}"
-                    )
+                    self.logger.debug(f"Sending a request - url: {self.url}, body: {str_body}, headers: {headers}")
 
                 try:
-                    async with session.request(
-                        "POST", self.url, **request_kwargs
-                    ) as res:
+                    async with session.request("POST", self.url, **request_kwargs) as res:  # type: ignore[arg-type, union-attr] # noqa: E501
                         try:
                             response_body = await res.text()
                             retry_response = RetryHttpResponse(
                                 status_code=res.status,
-                                headers=res.headers,
-                                data=response_body.encode("utf-8")
-                                if response_body is not None
-                                else None,
+                                headers=res.headers,  # type: ignore[arg-type]
+                                data=response_body.encode("utf-8") if response_body is not None else None,
                             )
                         except aiohttp.ContentTypeError:
-                            self.logger.debug(
-                                f"No response data returned from the following API call: {self.url}"
+                            self.logger.debug(f"No response data returned from the following API call: {self.url}")
+                            retry_response = RetryHttpResponse(
+                                status_code=res.status,
+                                headers=res.headers,  # type: ignore[arg-type]
                             )
 
                         if res.status == 429:
@@ -240,7 +231,7 @@ class AsyncWebhookClient:
                                 url=self.url,
                                 status_code=res.status,
                                 body=response_body,
-                                headers=res.headers,
+                                headers=res.headers,  # type: ignore[arg-type]
                             )
                             _debug_log_response(self.logger, resp)
                             return resp
@@ -256,8 +247,7 @@ class AsyncWebhookClient:
                         ):
                             if self.logger.level <= logging.DEBUG:
                                 self.logger.info(
-                                    f"A retry handler found: {type(handler).__name__} "
-                                    f"for POST {self.url} - {e}"
+                                    f"A retry handler found: {type(handler).__name__} " f"for POST {self.url} - {e}"
                                 )
                             await handler.prepare_for_next_attempt_async(
                                 state=retry_state,
@@ -272,10 +262,10 @@ class AsyncWebhookClient:
 
             if resp is not None:
                 return resp
-            raise last_error
+            raise last_error  # type: ignore[misc]
 
         finally:
             if not use_running_session:
-                await session.close()
+                await session.close()  # type: ignore[union-attr]
 
         return resp
