@@ -66,13 +66,9 @@ class WebhookClient:
         self.ssl = ssl
         self.proxy = proxy
         self.default_headers = default_headers if default_headers else {}
-        self.default_headers["User-Agent"] = get_user_agent(
-            user_agent_prefix, user_agent_suffix
-        )
+        self.default_headers["User-Agent"] = get_user_agent(user_agent_prefix, user_agent_suffix)
         self.logger = logger if logger is not None else logging.getLogger(__name__)
-        self.retry_handlers = (
-            retry_handlers if retry_handlers is not None else default_retry_handlers()
-        )
+        self.retry_handlers = retry_handlers if retry_handlers is not None else default_retry_handlers()
 
         if self.proxy is None or len(self.proxy.strip()) == 0:
             env_variable = load_http_proxy_from_env(self.logger)
@@ -90,6 +86,7 @@ class WebhookClient:
         delete_original: Optional[bool] = None,
         unfurl_links: Optional[bool] = None,
         unfurl_media: Optional[bool] = None,
+        metadata: Optional[Dict[str, Any]] = None,
         headers: Optional[Dict[str, str]] = None,
     ) -> WebhookResponse:
         """Performs a Slack API request and returns the result.
@@ -104,6 +101,7 @@ class WebhookClient:
             delete_original: True if you use this option for response_url requests
             unfurl_links: Option to indicate whether text url should unfurl
             unfurl_media: Option to indicate whether media url should unfurl
+            metadata: Metadata attached to the message
             headers: Request headers to append only for this request
 
         Returns:
@@ -121,13 +119,12 @@ class WebhookClient:
                 "delete_original": delete_original,
                 "unfurl_links": unfurl_links,
                 "unfurl_media": unfurl_media,
+                "metadata": metadata,
             },
             headers=headers,
         )
 
-    def send_dict(
-        self, body: Dict[str, Any], headers: Optional[Dict[str, str]] = None
-    ) -> WebhookResponse:
+    def send_dict(self, body: Dict[str, Any], headers: Optional[Dict[str, str]] = None) -> WebhookResponse:
         """Performs a Slack API request and returns the result.
 
         Args:
@@ -138,29 +135,23 @@ class WebhookClient:
             Webhook response
         """
         return self._perform_http_request(
-            body=_build_body(body),
+            body=_build_body(body),  # type: ignore[arg-type]
             headers=_build_request_headers(self.default_headers, headers),
         )
 
-    def _perform_http_request(
-        self, *, body: Dict[str, Any], headers: Dict[str, str]
-    ) -> WebhookResponse:
-        body = json.dumps(body)
+    def _perform_http_request(self, *, body: Dict[str, Any], headers: Dict[str, str]) -> WebhookResponse:
+        raw_body = json.dumps(body)
         headers["Content-Type"] = "application/json;charset=utf-8"
 
         if self.logger.level <= logging.DEBUG:
-            self.logger.debug(
-                f"Sending a request - url: {self.url}, body: {body}, headers: {headers}"
-            )
+            self.logger.debug(f"Sending a request - url: {self.url}, body: {raw_body}, headers: {headers}")
 
         url = self.url
         # NOTE: Intentionally ignore the `http_verb` here
         # Slack APIs accepts any API method requests with POST methods
-        req = Request(
-            method="POST", url=url, data=body.encode("utf-8"), headers=headers
-        )
+        req = Request(method="POST", url=url, data=raw_body.encode("utf-8"), headers=headers)
         resp = None
-        last_error = None
+        last_error = Exception("undefined internal error")
 
         retry_state = RetryState()
         counter_for_safety = 0
@@ -178,23 +169,19 @@ class WebhookClient:
                 # read the response body here
                 charset = e.headers.get_content_charset() or "utf-8"
                 response_body: str = e.read().decode(charset)
+                # As adding new values to HTTPError#headers can be ignored, building a new dict object here
+                response_headers = dict(e.headers.items())
                 resp = WebhookResponse(
                     url=url,
                     status_code=e.code,
                     body=response_body,
-                    headers=dict(e.headers.items()),
+                    headers=response_headers,
                 )
                 if e.code == 429:
                     # for backward-compatibility with WebClient (v.2.5.0 or older)
-                    if (
-                        "retry-after" not in resp.headers
-                        and "Retry-After" in resp.headers
-                    ):
+                    if "retry-after" not in resp.headers and "Retry-After" in resp.headers:
                         resp.headers["retry-after"] = resp.headers["Retry-After"]
-                    if (
-                        "Retry-After" not in resp.headers
-                        and "retry-after" in resp.headers
-                    ):
+                    if "Retry-After" not in resp.headers and "retry-after" in resp.headers:
                         resp.headers["Retry-After"] = resp.headers["retry-after"]
                 _debug_log_response(self.logger, resp)
 
@@ -203,9 +190,7 @@ class WebhookClient:
                 retry_response = RetryHttpResponse(
                     status_code=e.code,
                     headers={k: [v] for k, v in e.headers.items()},
-                    data=response_body.encode("utf-8")
-                    if response_body is not None
-                    else None,
+                    data=response_body.encode("utf-8") if response_body is not None else None,
                 )
                 for handler in self.retry_handlers:
                     if handler.can_retry(
@@ -231,9 +216,7 @@ class WebhookClient:
 
             except Exception as err:
                 last_error = err
-                self.logger.error(
-                    f"Failed to send a request to Slack API server: {err}"
-                )
+                self.logger.error(f"Failed to send a request to Slack API server: {err}")
 
                 # Try to find a retry handler for this error
                 retry_request = RetryHttpRequest.from_urllib_http_request(req)
@@ -254,9 +237,7 @@ class WebhookClient:
                             response=None,
                             error=err,
                         )
-                        self.logger.info(
-                            f"Going to retry the same request: {req.method} {req.full_url}"
-                        )
+                        self.logger.info(f"Going to retry the same request: {req.method} {req.full_url}")
                         break
 
                 if retry_state.next_attempt_requested is False:
@@ -277,27 +258,22 @@ class WebhookClient:
                         HTTPSHandler(context=self.ssl),
                     )
                 else:
-                    raise SlackRequestError(
-                        f"Invalid proxy detected: {self.proxy} must be a str value"
-                    )
+                    raise SlackRequestError(f"Invalid proxy detected: {self.proxy} must be a str value")
         else:
             raise SlackRequestError(f"Invalid URL detected: {url}")
 
-        # NOTE: BAN-B310 is already checked above
         http_resp: Optional[HTTPResponse] = None
         if opener:
-            http_resp = opener.open(req, timeout=self.timeout)  # skipcq: BAN-B310
+            http_resp = opener.open(req, timeout=self.timeout)
         else:
-            http_resp = urlopen(  # skipcq: BAN-B310
-                req, context=self.ssl, timeout=self.timeout
-            )
-        charset: str = http_resp.headers.get_content_charset() or "utf-8"
-        response_body: str = http_resp.read().decode(charset)
+            http_resp = urlopen(req, context=self.ssl, timeout=self.timeout)
+        charset: str = http_resp.headers.get_content_charset() or "utf-8"  # type: ignore[union-attr]
+        response_body: str = http_resp.read().decode(charset)  # type: ignore[union-attr]
         resp = WebhookResponse(
             url=url,
-            status_code=http_resp.status,
+            status_code=http_resp.status,  # type: ignore[union-attr]
             body=response_body,
-            headers=http_resp.headers,
+            headers=http_resp.headers,  # type: ignore[arg-type, union-attr]
         )
         _debug_log_response(self.logger, resp)
         return resp
